# CHANGELOG

PyPI grscheller.boring-math project.

## Semantic Versioning

Strict 3 digit semantic versioning.

- **MAJOR** version incremented for incompatible API changes
- **MINOR** version incremented for backward compatible added functionality
- **PATCH** version incremented for backward compatible bug fixes

See [Semantic Versioning 2.0.0](https://semver.org).

## Releases and other important milestones

### Version 0.8.0 - PyPI release date 2025-08-04

Minimal code changes, redid infrastructure similarly to what was
done for pythonic-fp. Still need to switch over to Sphinx for docs.

### Version 0.7.1 - PyPI release date 2025-07-14

Fixed munged CHANGELOG and Documentation links for PyPI

### Version 0.7.0 - PyPI release date 2025-07-14

First version to use pythonic_fp namespace, no longer using dtools
namespace packages.

### Version 0.5.0 - PyPI release date 2025-01-21

- First PyPI release as bm.probability-distributions
- new doc location is
  [here](https://grscheller.github.io/boring-math-docs/)

### Version 0.4.7 - PyPI release date 2024-11-18

- Some minor additions
- consistency changes across all grscheller namespace PyPI repos
